Index: chrome/browser/printing/print_dialog_cloud.cc |
diff --git a/chrome/browser/printing/print_dialog_cloud.cc b/chrome/browser/printing/print_dialog_cloud.cc |
index 6cb19322f8bf2e607fcd6d4b7a0366678e433f04..f80240d2124c8b8eaec963ed9347a6eba8c7de60 100644 |
--- a/chrome/browser/printing/print_dialog_cloud.cc |
+++ b/chrome/browser/printing/print_dialog_cloud.cc |
@@ -54,7 +54,7 @@ |
// The constructor for PrintDialogCloud creates a |
// CloudPrintHtmlDialogDelegate and asks the current active browser to |
// show an HTML dialog using that class as the delegate. That class |
// hands in the kCloudPrintResourcesURL as the URL to visit. That is |
// recognized by the GetWebUIFactoryFunction as a signal to create an |
// ExternalHtmlDialogUI. |
@@ -424,7 +424,7 @@ void CloudPrintHtmlDialogDelegate::Init(int width, int height, |
const std::string& json_arguments) { |
// This information is needed to show the dialog HTML content. |
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::UI)); |
- params_.url = GURL(chrome::kCloudPrintResourcesURL); |
+ params_.url = GURL(chrome::kChromeUICloudPrintResourcesURL); |
params_.height = height; |
params_.width = width; |
params_.json_input = json_arguments; |
@@ -54,7 +54,7 @@ |
// CloudPrintHtmlDialogDelegate and asks the current active browser to |
// show an HTML dialog using that class as the delegate. That class |
-// hands in the kCloudPrintResourcesURL as the URL to visit. That is |
+// hands in the kChromeUICloudPrintResourcesURL as the URL to visit. That is |
// recognized by the GetWebUIFactoryFunction as a signal to create an |
// ExternalHtmlDialogUI. |